within InaMo.Cells.VariableCa;
model ACell "full atrial cell model following equations from Lindblad et al. (1996)"
  extends Modelica.Icons.UnderConstruction;
  extends InaMo.Currents.Interfaces.TwoPinCell;
  inner parameter SI.Volume v_ca = 1 "volume of comparment from which Ca2+ is transported across the cell membrane"; // FIXME unsure if this naming is correct
  inner parameter SI.Volume v_cyto = 1 "volume of cytosol";
  inner parameter SI.Volume v_nsr = 1 "volume of network sarcoplasmic reticulum";
  inner parameter SI.Volume v_jsr = 1 "volume of junctional sarcoplasmic reticulum";
  inner parameter SI.Temperature temp = 310 "temperature of cell medium";
  inner parameter SI.Concentration ca_ex = 1 "extracellular calcium concentration";
  inner parameter SI.Concentration na_ex = 1 "extracellular sodium concentration";
  inner parameter SI.Concentration k_ex = 1 "extracellular potassium concentration";
  inner parameter PermeabilityFM na_p = 1 "permeability of cell membrane for sodium";
  inner parameter Real FoRT = 1 "result of F/(R*T)";
  InaMo.Currents.Atrial.SodiumChannelA na "I_Na";
  InaMo.Currents.Atrial.LTypeCalciumChannelA cal "I_Ca,L";
  InaMo.Currents.Atrial.TTypeCalciumChannelA cat "I_Ca,T";
  InaMo.Currents.Atrial.TransientOutwardChannelA to "I_to";
  InaMo.Currents.Atrial.RapidDelayedRectifierChannelA kr "I_K,r";
  InaMo.Currents.Atrial.SlowDelayedRectifierChannelA ks "I_K,s";
  InaMo.Currents.Atrial.InwardRectifierA kir "I_K1";
  InaMo.Currents.Atrial.BackgroundChannelNa bna "I_B,Na";
  InaMo.Currents.Atrial.BackgroundChannelCa bca "I_B,Ca";
  InaMo.Currents.Atrial.BackgroundChannelCl bcl "I_B,Cl";
  InaMo.Currents.Atrial.CalciumPump cap "I_CaP";
  InaMo.Currents.Atrial.SodiumPotassiumPumpA nak "I_NaK";
  InaMo.Currents.Atrial.SodiumCalciumExchangerA naca "I_NaCa";
  InaMo.Concentrations.Basic.Compartment na_in "intracellular sodium";
  InaMo.Concentrations.Basic.Compartment k_in "intracellular potassium";
  InaMo.Concentrations.Atrial.CaHandlingA ca(v_m=l2.v) "intracellular Ca2+ handling by SR and buffers";
  InaMo.Membrane.LipidBilayer l2 "membrane as capacitor";
equation
  connect(l2.p, p);
  connect(l2.n, n);
  connect(l2.p, na.p);
  connect(l2.n, na.n);
  connect(l2.p, cal.p);
  connect(l2.n, cal.n);
  connect(l2.p, cat.p);
  connect(l2.n, cat.n);
  connect(l2.p, to.p);
  connect(l2.n, to.n);
  connect(l2.p, kr.p);
  connect(l2.n, kr.n);
  connect(l2.p, ks.p);
  connect(l2.n, ks.n);
  connect(l2.p, kir.p);
  connect(l2.n, kir.n);
  connect(l2.p, bna.p);
  connect(l2.n, bna.n);
  connect(l2.p, bca.p);
  connect(l2.n, bca.n);
  connect(l2.p, bcl.p);
  connect(l2.n, bcl.n);
  connect(l2.p, cap.p);
  connect(l2.n, cap.n);
  connect(l2.p, nak.p);
  connect(l2.n, nak.n);
  connect(l2.p, naca.p);
  connect(l2.n, naca.n);
  connect(ca.ca_cyto, cal.ca);
  connect(ca.ca_cyto, cat.ca);
  connect(ca.ca_cyto, bca.ca);
  connect(ca.ca_cyto, cap.ca);
  connect(ca.ca_cyto, naca.ca);
  connect(na_in.substance, na.na);
  connect(na_in.substance, bna.na);
  connect(na_in.substance, nak.na);
  connect(na_in.substance, naca.na);
  connect(k_in.substance, to.k);
  connect(k_in.substance, kr.k);
  connect(k_in.substance, ks.k);
  connect(k_in.substance, kir.k);
  connect(k_in.substance, nak.k);
annotation(Documentation(info="<html>
  <p>
    This model represents a rabbit atrial muscle cell with equations by
    Lindblad et al. (1996).
    It is used by Inada et al. in their full 1D-model of the rabbit
    atrioventricular node as &quot;AM&quot; cell type along with the sinoatrial node
    cells SAN by Zhang et al. (2000) and their own AN, N, and NH cell models.
  </p>
  <p>
    NOTE: Currently this model can be compiled, but not simulated, since our
    focus was on the AN, N, and NH cell types.
  </p>
</html>"));
end ACell;
